Class: Google::Cloud::Redis::Cluster::V1beta1::Backup
- Inherits:
-
Object
- Object
- Google::Cloud::Redis::Cluster::V1beta1::Backup
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb
Overview
Backup of a cluster.
Defined Under Namespace
Modules: BackupType, State
Instance Attribute Summary collapse
-
#backup_files ⇒ ::Array<::Google::Cloud::Redis::Cluster::V1beta1::BackupFile>
readonly
Output only.
-
#backup_type ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::Backup::BackupType
readonly
Output only.
-
#cluster ⇒ ::String
readonly
Output only.
-
#cluster_uid ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#encryption_info ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::EncryptionInfo
readonly
Output only.
-
#engine_version ⇒ ::String
readonly
Output only.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#node_type ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::NodeType
readonly
Output only.
-
#replica_count ⇒ ::Integer
readonly
Output only.
-
#shard_count ⇒ ::Integer
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::Backup::State
readonly
Output only.
-
#total_size_bytes ⇒ ::Integer
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
Instance Attribute Details
#backup_files ⇒ ::Array<::Google::Cloud::Redis::Cluster::V1beta1::BackupFile> (readonly)
Returns Output only. List of backup files of the backup.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#backup_type ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::Backup::BackupType (readonly)
Returns Output only. Type of the backup.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#cluster ⇒ ::String (readonly)
Returns Output only. Cluster resource path of this backup.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#cluster_uid ⇒ ::String (readonly)
Returns Output only. Cluster uid of this backup.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the backup was created.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#encryption_info ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::EncryptionInfo (readonly)
Returns Output only. Encryption information of the backup.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#engine_version ⇒ ::String (readonly)
Returns Output only. redis-7.2, valkey-7.5.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#expire_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time when the backup will expire.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#name ⇒ ::String
Returns Identifier. Full resource path of the backup. the last part of the name is the backup id with the following format: [YYYYMMDDHHMMSS]_[Shorted Cluster UID] OR customer specified while backup cluster. Example: 20240515123000_1234.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#node_type ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::NodeType (readonly)
Returns Output only. Node type of the cluster.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#replica_count ⇒ ::Integer (readonly)
Returns Output only. Number of replicas for the cluster.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#shard_count ⇒ ::Integer (readonly)
Returns Output only. Number of shards for the cluster.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#state ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::Backup::State (readonly)
Returns Output only. State of the backup.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#total_size_bytes ⇒ ::Integer (readonly)
Returns Output only. Total size of the backup in bytes.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |
#uid ⇒ ::String (readonly)
Returns Output only. System assigned unique identifier of the backup.
632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 632 class Backup include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup. module BackupType # The default value, not set. BACKUP_TYPE_UNSPECIFIED = 0 # On-demand backup. ON_DEMAND = 1 # Automated backup. AUTOMATED = 2 end # State of the backup. module State # The default value, not set. STATE_UNSPECIFIED = 0 # The backup is being created. CREATING = 1 # The backup is active to be used. ACTIVE = 2 # The backup is being deleted. DELETING = 3 # The backup is currently suspended due to reasons like project deletion, # billing account closure, etc. SUSPENDED = 4 end end |