Class: Google::Cloud::Redis::Cluster::V1beta1::CertificateAuthority

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb

Overview

Redis cluster certificate authority

Defined Under Namespace

Classes: ManagedCertificateAuthority

Instance Attribute Summary collapse

Instance Attribute Details

#managed_server_ca::Google::Cloud::Redis::Cluster::V1beta1::CertificateAuthority::ManagedCertificateAuthority



1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1048

class CertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Redis::Cluster::V1beta1::CertificateAuthority::ManagedCertificateAuthority::CertChain>]
  #     The PEM encoded CA certificate chains for redis managed
  #     server authentication
  class ManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class CertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#name::String

Returns Identifier. Unique name of the resource in this scope including project, location and cluster using the form: projects/{project}/locations/{location}/clusters/{cluster}/certificateAuthority.

Returns:

  • (::String)

    Identifier. Unique name of the resource in this scope including project, location and cluster using the form: projects/{project}/locations/{location}/clusters/{cluster}/certificateAuthority



1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1048

class CertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Redis::Cluster::V1beta1::CertificateAuthority::ManagedCertificateAuthority::CertChain>]
  #     The PEM encoded CA certificate chains for redis managed
  #     server authentication
  class ManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class CertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end