Class: Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb

Overview

Configuration of the persistence functionality.

Defined Under Namespace

Modules: PersistenceMode Classes: AOFConfig, RDBConfig

Instance Attribute Summary collapse

Instance Attribute Details

#aof_config::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::AOFConfig

Returns Optional. AOF configuration. This field will be ignored if mode is not AOF.

Returns:



1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1080

class ClusterPersistenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of the RDB based persistence.
  # @!attribute [rw] rdb_snapshot_period
  #   @return [::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::RDBConfig::SnapshotPeriod]
  #     Optional. Period between RDB snapshots.
  # @!attribute [rw] rdb_snapshot_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time that the first snapshot was/will be attempted, and to
  #     which future snapshots will be aligned. If not provided, the current time
  #     will be used.
  class RDBConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Available snapshot periods.
    module SnapshotPeriod
      # Not set.
      SNAPSHOT_PERIOD_UNSPECIFIED = 0

      # One hour.
      ONE_HOUR = 1

      # Six hours.
      SIX_HOURS = 2

      # Twelve hours.
      TWELVE_HOURS = 3

      # Twenty four hours.
      TWENTY_FOUR_HOURS = 4
    end
  end

  # Configuration of the AOF based persistence.
  # @!attribute [rw] append_fsync
  #   @return [::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::AOFConfig::AppendFsync]
  #     Optional. fsync configuration.
  class AOFConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Available fsync modes.
    module AppendFsync
      # Not set. Default: EVERYSEC
      APPEND_FSYNC_UNSPECIFIED = 0

      # Never fsync. Normally Linux will flush data every 30 seconds with this
      # configuration, but it's up to the kernel's exact tuning.
      NO = 1

      # fsync every second. Fast enough, and you may lose 1 second of data if
      # there is a disaster
      EVERYSEC = 2

      # fsync every time new write commands are appended to the AOF. It has the
      # best data loss protection at the cost of performance
      ALWAYS = 3
    end
  end

  # Available persistence modes.
  module PersistenceMode
    # Not set.
    PERSISTENCE_MODE_UNSPECIFIED = 0

    # Persistence is disabled, and any snapshot data is deleted.
    DISABLED = 1

    # RDB based persistence is enabled.
    RDB = 2

    # AOF based persistence is enabled.
    AOF = 3
  end
end

#mode::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::PersistenceMode

Returns Optional. The mode of persistence.



1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1080

class ClusterPersistenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of the RDB based persistence.
  # @!attribute [rw] rdb_snapshot_period
  #   @return [::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::RDBConfig::SnapshotPeriod]
  #     Optional. Period between RDB snapshots.
  # @!attribute [rw] rdb_snapshot_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time that the first snapshot was/will be attempted, and to
  #     which future snapshots will be aligned. If not provided, the current time
  #     will be used.
  class RDBConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Available snapshot periods.
    module SnapshotPeriod
      # Not set.
      SNAPSHOT_PERIOD_UNSPECIFIED = 0

      # One hour.
      ONE_HOUR = 1

      # Six hours.
      SIX_HOURS = 2

      # Twelve hours.
      TWELVE_HOURS = 3

      # Twenty four hours.
      TWENTY_FOUR_HOURS = 4
    end
  end

  # Configuration of the AOF based persistence.
  # @!attribute [rw] append_fsync
  #   @return [::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::AOFConfig::AppendFsync]
  #     Optional. fsync configuration.
  class AOFConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Available fsync modes.
    module AppendFsync
      # Not set. Default: EVERYSEC
      APPEND_FSYNC_UNSPECIFIED = 0

      # Never fsync. Normally Linux will flush data every 30 seconds with this
      # configuration, but it's up to the kernel's exact tuning.
      NO = 1

      # fsync every second. Fast enough, and you may lose 1 second of data if
      # there is a disaster
      EVERYSEC = 2

      # fsync every time new write commands are appended to the AOF. It has the
      # best data loss protection at the cost of performance
      ALWAYS = 3
    end
  end

  # Available persistence modes.
  module PersistenceMode
    # Not set.
    PERSISTENCE_MODE_UNSPECIFIED = 0

    # Persistence is disabled, and any snapshot data is deleted.
    DISABLED = 1

    # RDB based persistence is enabled.
    RDB = 2

    # AOF based persistence is enabled.
    AOF = 3
  end
end

#rdb_config::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::RDBConfig

Returns Optional. RDB configuration. This field will be ignored if mode is not RDB.

Returns:



1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1080

class ClusterPersistenceConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration of the RDB based persistence.
  # @!attribute [rw] rdb_snapshot_period
  #   @return [::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::RDBConfig::SnapshotPeriod]
  #     Optional. Period between RDB snapshots.
  # @!attribute [rw] rdb_snapshot_start_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Optional. The time that the first snapshot was/will be attempted, and to
  #     which future snapshots will be aligned. If not provided, the current time
  #     will be used.
  class RDBConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Available snapshot periods.
    module SnapshotPeriod
      # Not set.
      SNAPSHOT_PERIOD_UNSPECIFIED = 0

      # One hour.
      ONE_HOUR = 1

      # Six hours.
      SIX_HOURS = 2

      # Twelve hours.
      TWELVE_HOURS = 3

      # Twenty four hours.
      TWENTY_FOUR_HOURS = 4
    end
  end

  # Configuration of the AOF based persistence.
  # @!attribute [rw] append_fsync
  #   @return [::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::AOFConfig::AppendFsync]
  #     Optional. fsync configuration.
  class AOFConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Available fsync modes.
    module AppendFsync
      # Not set. Default: EVERYSEC
      APPEND_FSYNC_UNSPECIFIED = 0

      # Never fsync. Normally Linux will flush data every 30 seconds with this
      # configuration, but it's up to the kernel's exact tuning.
      NO = 1

      # fsync every second. Fast enough, and you may lose 1 second of data if
      # there is a disaster
      EVERYSEC = 2

      # fsync every time new write commands are appended to the AOF. It has the
      # best data loss protection at the cost of performance
      ALWAYS = 3
    end
  end

  # Available persistence modes.
  module PersistenceMode
    # Not set.
    PERSISTENCE_MODE_UNSPECIFIED = 0

    # Persistence is disabled, and any snapshot data is deleted.
    DISABLED = 1

    # RDB based persistence is enabled.
    RDB = 2

    # AOF based persistence is enabled.
    AOF = 3
  end
end