Class: Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::AOFConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb

Overview

Configuration of the AOF based persistence.

Defined Under Namespace

Modules: AppendFsync

Instance Attribute Summary collapse

Instance Attribute Details

#append_fsync::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::AOFConfig::AppendFsync

Returns Optional. fsync configuration.



1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1120

class AOFConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Available fsync modes.
  module AppendFsync
    # Not set. Default: EVERYSEC
    APPEND_FSYNC_UNSPECIFIED = 0

    # Never fsync. Normally Linux will flush data every 30 seconds with this
    # configuration, but it's up to the kernel's exact tuning.
    NO = 1

    # fsync every second. Fast enough, and you may lose 1 second of data if
    # there is a disaster
    EVERYSEC = 2

    # fsync every time new write commands are appended to the AOF. It has the
    # best data loss protection at the cost of performance
    ALWAYS = 3
  end
end