Class: Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::RDBConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::RDBConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb
Overview
Configuration of the RDB based persistence.
Defined Under Namespace
Modules: SnapshotPeriod
Instance Attribute Summary collapse
-
#rdb_snapshot_period ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::RDBConfig::SnapshotPeriod
Optional.
-
#rdb_snapshot_start_time ⇒ ::Google::Protobuf::Timestamp
Optional.
Instance Attribute Details
#rdb_snapshot_period ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::ClusterPersistenceConfig::RDBConfig::SnapshotPeriod
Returns Optional. Period between RDB snapshots.
1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1093 class RDBConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Available snapshot periods. module SnapshotPeriod # Not set. SNAPSHOT_PERIOD_UNSPECIFIED = 0 # One hour. ONE_HOUR = 1 # Six hours. SIX_HOURS = 2 # Twelve hours. TWELVE_HOURS = 3 # Twenty four hours. TWENTY_FOUR_HOURS = 4 end end |
#rdb_snapshot_start_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The time that the first snapshot was/will be attempted, and to which future snapshots will be aligned. If not provided, the current time will be used.
1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1093 class RDBConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Available snapshot periods. module SnapshotPeriod # Not set. SNAPSHOT_PERIOD_UNSPECIFIED = 0 # One hour. ONE_HOUR = 1 # Six hours. SIX_HOURS = 2 # Twelve hours. TWELVE_HOURS = 3 # Twenty four hours. TWENTY_FOUR_HOURS = 4 end end |