Class: Google::Cloud::Redis::Cluster::V1beta1::EncryptionInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Redis::Cluster::V1beta1::EncryptionInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb
Overview
EncryptionInfo describes the encryption information of a cluster or a backup.
Defined Under Namespace
Modules: KmsKeyState, Type
Instance Attribute Summary collapse
-
#encryption_type ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::EncryptionInfo::Type
readonly
Output only.
-
#kms_key_primary_state ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::EncryptionInfo::KmsKeyState
readonly
Output only.
-
#kms_key_versions ⇒ ::Array<::String>
readonly
Output only.
-
#last_update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#encryption_type ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::EncryptionInfo::Type (readonly)
Returns Output only. Type of encryption.
1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1235 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#kms_key_primary_state ⇒ ::Google::Cloud::Redis::Cluster::V1beta1::EncryptionInfo::KmsKeyState (readonly)
Returns Output only. The state of the primary version of the KMS key perceived by the system. This field is not populated in backups.
1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1235 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#kms_key_versions ⇒ ::Array<::String> (readonly)
Returns Output only. KMS key versions that are being used to protect the data at-rest.
1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1235 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |
#last_update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The most recent time when the encryption info was updated.
1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 |
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 1235 class EncryptionInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible encryption types. module Type # Encryption type not specified. Defaults to GOOGLE_DEFAULT_ENCRYPTION. TYPE_UNSPECIFIED = 0 # The data is encrypted at rest with a key that is fully managed by Google. # No key version will be populated. This is the default state. GOOGLE_DEFAULT_ENCRYPTION = 1 # The data is encrypted at rest with a key that is managed by the customer. # KMS key versions will be populated. CUSTOMER_MANAGED_ENCRYPTION = 2 end # The state of the KMS key perceived by the system. Refer to the public # documentation for the impact of each state. module KmsKeyState # The default value. This value is unused. KMS_KEY_STATE_UNSPECIFIED = 0 # The KMS key is enabled and correctly configured. ENABLED = 1 # Permission denied on the KMS key. PERMISSION_DENIED = 2 # The KMS key is disabled. DISABLED = 3 # The KMS key is destroyed. DESTROYED = 4 # The KMS key is scheduled to be destroyed. DESTROY_SCHEDULED = 5 # The EKM key is unreachable. EKM_KEY_UNREACHABLE_DETECTED = 6 # Billing is disabled for the project. BILLING_DISABLED = 7 # All other unknown failures. UNKNOWN_FAILURE = 8 end end |