Class: Google::Cloud::Redis::Cluster::V1beta1::SharedRegionalCertificateAuthority

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb

Overview

Shared regional certificate authority

Defined Under Namespace

Classes: RegionalManagedCertificateAuthority

Instance Attribute Summary collapse

Instance Attribute Details

#managed_server_ca::Google::Cloud::Redis::Cluster::V1beta1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority

Returns CA certificate chains for redis managed server authentication.

Returns:



973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 973

class SharedRegionalCertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CA certificate chains for redis managed server authentication.
  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Redis::Cluster::V1beta1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority::RegionalCertChain>]
  #     The PEM encoded CA certificate chains for redis managed
  #     server authentication
  class RegionalManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The certificates that form the CA chain, from leaf to root order.
    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class RegionalCertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#name::String

Returns Identifier. Unique name of the resource in this scope including project and location using the form: projects/{project}/locations/{location}/sharedRegionalCertificateAuthority.

Returns:

  • (::String)

    Identifier. Unique name of the resource in this scope including project and location using the form: projects/{project}/locations/{location}/sharedRegionalCertificateAuthority



973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
# File 'proto_docs/google/cloud/redis/cluster/v1beta1/cloud_redis_cluster.rb', line 973

class SharedRegionalCertificateAuthority
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CA certificate chains for redis managed server authentication.
  # @!attribute [rw] ca_certs
  #   @return [::Array<::Google::Cloud::Redis::Cluster::V1beta1::SharedRegionalCertificateAuthority::RegionalManagedCertificateAuthority::RegionalCertChain>]
  #     The PEM encoded CA certificate chains for redis managed
  #     server authentication
  class RegionalManagedCertificateAuthority
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The certificates that form the CA chain, from leaf to root order.
    # @!attribute [rw] certificates
    #   @return [::Array<::String>]
    #     The certificates that form the CA chain, from leaf to root order.
    class RegionalCertChain
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end